.. py:currentmodule:: drdmannturb

Spectra Fitting with DRD Calibration
====================================

Half of DRDMannTurb provides models for learning wind spectra from data. 

The package has `Tensorboard <https://pytorch.org/docs/stable/tensorboard.html>`__ integration, which performs all of the logging and post-training visualization of neural network models used in the package.  

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   data_types_and_classes

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 2

   calibration 

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 2

   losses

.. raw:: html

    <hr>

.. toctree::
   :maxdepth: 2

   interpolation 

.. raw:: html

   <hr>


.. toctree::
   :maxdepth: 2

   tb_loss 